import { ConstructFactory, FunctionResources, ResourceProvider } from '@aws-amplify/plugin-types';
import { Construct } from 'constructs';
/**
 * Entry point for defining a function in the Amplify ecosystem
 */
export declare const defineFunction: (props?: FunctionProps) => ConstructFactory<Construct & ResourceProvider<FunctionResources>>;
export type FunctionProps = {
    /**
     * A name for the function.
     * Defaults to the basename of the entry path if specified.
     * If no entry is specified, defaults to the directory name in which this function is defined.
     *
     * Example:
     * If entry is `./scheduled-db-backup.ts` the name will default to "scheduled-db-backup"
     * If entry is not set and the function is defined in `amplify/functions/db-backup/resource.ts` the name will default to "db-backup"
     */
    name?: string;
    /**
     * The path to the file that contains the function entry point.
     * If this is a relative path, it is computed relative to the file where this function is defined
     *
     * Defaults to './handler.ts'
     */
    entry?: string;
};
//# sourceMappingURL=factory.d.ts.map